package com.jianshui.invoice.service;

import java.util.List;

import com.jianshui.common.core.domain.AjaxResult;
import com.jianshui.invoice.domain.BillInfo;

/**
 * 开票信息Service接口
 *
 * @author Gong Quanlin
 * @date 2022-03-06
 */
public interface IBillInfoService {
    /**
     * 查询开票信息
     *
     * @param id 开票信息主键
     * @return 开票信息
     */
    public BillInfo selectBillInfoById(Long id);

    /**
     * 查询开票信息列表
     *
     * @param billInfo 开票信息
     * @return 开票信息集合
     */
    public List<BillInfo> selectBillInfoList(BillInfo billInfo);

    /**
     * 新增开票信息
     *
     * @param billInfo 开票信息
     * @return 结果
     */
    public int insertBillInfo(BillInfo billInfo);

    /**
     * 修改开票信息
     *
     * @param billInfo 开票信息
     * @return 结果
     */
    public int updateBillInfo(BillInfo billInfo);

    /**
     * 批量删除开票信息
     *
     * @param ids 需要删除的开票信息主键集合
     * @return 结果
     */
    public int deleteBillInfoByIds(Long[] ids);

    /**
     * 删除开票信息信息
     *
     * @param id 开票信息主键
     * @return 结果
     */
    public int deleteBillInfoById(Long id);

    /**
     * 主动回调
     *
     * @param id billInfoId
     * @return
     */
    public AjaxResult pushBillInfo(Long id);
}
